Day | Pair No | Value
--- | --- | ---
Понеділок | 1 |
Понеділок | 2 | АЕП (Онлайн лек.) Осадчук П. І. Ідентифікатор/Код ﻿Petr Osadchuk приглашает вас на запланированную конференцию: Zoom. Тема: Автоматизований електропривод Идентификатор конференции: 840 1144 5726 Код доступа: ZCp5dT
Понеділок | 3 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код ﻿switiy@yahoo.com приглашает вас на запланированную конференцию: Zoom. Тема: Лекція з ЛКТРС Время: 5 сент. 2022 11:30 AM Киев Подключиться к конференции Zoom https://us04web.zoom.us/j/76523140585?pwd=Q8oh6Lui2gI8f466Glabetu1wDtyIG.1 Идентификатор конференции: 765 2314 0585 Код доступа: 2022
Понеділок | 4 |
Понеділок | 5 |
Вівторок | 1 |
Вівторок | 2 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код
Вівторок | 3 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код
Вівторок | 4 |
Вівторок | 5 |
Середа | 1 |
Середа | 2 | БЖДтаООП (Онлайн практ.) Неменуща С. М. Ідентифікатор/Код ZOOM: 266 077 8838 Код доступа: 3evcc6 телеграм/вайбер 0956471608 пошта s_nem_od@ukr.net
Середа | 3 | БЖДтаООП (Онлайн практ.) Неменуща С. М. Ідентифікатор/Код ZOOM: 266 077 8838 Код доступа: 3evcc6 телеграм/вайбер 0956471608 пошта s_nem_od@ukr.net
Середа | 4 |
Середа | 5 |
Четвер | 1 |
Четвер | 2 | ЕтаМПТ (Онлайн лек.) Мазур О. В. Ідентифікатор/Код 6595926813 Код 7ZD2gN
Четвер | 3 | ЕтаМПТ (Онлайн лек.) Мазур О. В. Ідентифікатор/Код 6595926813 Код 7ZD2gN
Четвер | 4 |
Четвер | 5 |
П`ятниця | 1 |
П`ятниця | 2 |
П`ятниця | 3 | ТАК (Онлайн лек.) Хобін В. А. Ідентифікатор/Код Подключиться к конференции Zoom https://us04web.zoom.us/j/3644954894?pwd=UldpSi83SEptY2E1aUprR0hoNXRpZz09 Идентификатор конференции: 364 495 4894 Код доступа: 176062
П`ятниця | 4 |
П`ятниця | 5 |
Субота | 1 |
Субота | 2 |
Субота | 3 |
Субота | 4 |
Субота | 5 |